# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/baremetal/v1alpha/server.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/baremetal/v1alpha/server.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.baremetal.v1alpha import disk_pb2 as yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_disk__pb2
from yandex.cloud.baremetal.v1alpha import storage_pb2 as yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_storage__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+yandex/cloud/baremetal/v1alpha/server.proto\x12\x1eyandex.cloud.baremetal.v1alpha\x1a\x1fgoogle/protobuf/timestamp.proto\x1a)yandex/cloud/baremetal/v1alpha/disk.proto\x1a,yandex/cloud/baremetal/v1alpha/storage.proto\"\xe6\x06\n\x06Server\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08\x63loud_id\x18\x02 \x01(\t\x12\x11\n\tfolder_id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x0f\n\x07zone_id\x18\x06 \x01(\t\x12\x18\n\x10hardware_pool_id\x18\x07 \x01(\t\x12=\n\x06status\x18\t \x01(\x0e\x32-.yandex.cloud.baremetal.v1alpha.Server.Status\x12?\n\x0bos_settings\x18\n \x01(\x0b\x32*.yandex.cloud.baremetal.v1alpha.OsSettings\x12L\n\x12network_interfaces\x18\x12 \x03(\x0b\x32\x30.yandex.cloud.baremetal.v1alpha.NetworkInterface\x12\x18\n\x10\x63onfiguration_id\x18\x14 \x01(\t\x12\x33\n\x05\x64isks\x18\x15 \x03(\x0b\x32$.yandex.cloud.baremetal.v1alpha.Disk\x12.\n\ncreated_at\x18\x64 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x43\n\x06labels\x18\xc8\x01 \x03(\x0b\x32\x32.yandex.cloud.baremetal.v1alpha.Server.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd8\x01\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x10\n\x0cPROVISIONING\x10\x01\x12\x0c\n\x08STOPPING\x10\x03\x12\x0b\n\x07STOPPED\x10\x04\x12\x0c\n\x08STARTING\x10\x05\x12\x0e\n\nRESTARTING\x10\x06\x12\t\n\x05\x45RROR\x10\x07\x12\x10\n\x08\x44\x45LETING\x10\x08\x1a\x02\x08\x01\x12\x10\n\x0cREINSTALLING\x10\t\x12\x0c\n\x08UPDATING\x10\n\x12\x0f\n\x0bQUARANTINED\x10\x0c\x12\x0b\n\x07RUNNING\x10\x0e\"\x04\x08\x02\x10\x02\"\x04\x08\x0b\x10\x0b\"\x04\x08\r\x10\rJ\x04\x08\x08\x10\tJ\x04\x08\x0b\x10\x0cJ\x04\x08\x0c\x10\rJ\x04\x08\x0f\x10\x12J\x04\x08\x13\x10\x14J\x04\x08\x16\x10\x17J\x04\x08\x17\x10\x18J\x04\x08\r\x10\x0eJ\x04\x08\x0e\x10\x0fJ\x04\x08\x18\x10\x64J\x05\x08\x65\x10\xc8\x01\"\x87\x02\n\x10NetworkInterface\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0bmac_address\x18\x02 \x01(\t\x12\x12\n\nip_address\x18\x03 \x01(\t\x12W\n\x0eprivate_subnet\x18\x07 \x01(\x0b\x32=.yandex.cloud.baremetal.v1alpha.PrivateSubnetNetworkInterfaceH\x00\x12U\n\rpublic_subnet\x18\x08 \x01(\x0b\x32<.yandex.cloud.baremetal.v1alpha.PublicSubnetNetworkInterfaceH\x00\x42\x08\n\x06subnetJ\x04\x08\x04\x10\x07\":\n\x1dPrivateSubnetNetworkInterface\x12\x19\n\x11private_subnet_id\x18\x01 \x01(\t\"8\n\x1cPublicSubnetNetworkInterface\x12\x18\n\x10public_subnet_id\x18\x01 \x01(\t\"q\n\nOsSettings\x12\x10\n\x08image_id\x18\x01 \x01(\t\x12\x16\n\x0essh_public_key\x18\x02 \x01(\t\x12\x39\n\x08storages\x18\x03 \x03(\x0b\x32\'.yandex.cloud.baremetal.v1alpha.StorageBr\n\"yandex.cloud.api.baremetal.v1alphaZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/baremetal/v1alpha;baremetalb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.baremetal.v1alpha.server_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"yandex.cloud.api.baremetal.v1alphaZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/baremetal/v1alpha;baremetal'
  _globals['_SERVER_LABELSENTRY']._loaded_options = None
  _globals['_SERVER_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_SERVER_STATUS'].values_by_name["DELETING"]._loaded_options = None
  _globals['_SERVER_STATUS'].values_by_name["DELETING"]._serialized_options = b'\010\001'
  _globals['_SERVER']._serialized_start=202
  _globals['_SERVER']._serialized_end=1072
  _globals['_SERVER_LABELSENTRY']._serialized_start=741
  _globals['_SERVER_LABELSENTRY']._serialized_end=786
  _globals['_SERVER_STATUS']._serialized_start=789
  _globals['_SERVER_STATUS']._serialized_end=1005
  _globals['_NETWORKINTERFACE']._serialized_start=1075
  _globals['_NETWORKINTERFACE']._serialized_end=1338
  _globals['_PRIVATESUBNETNETWORKINTERFACE']._serialized_start=1340
  _globals['_PRIVATESUBNETNETWORKINTERFACE']._serialized_end=1398
  _globals['_PUBLICSUBNETNETWORKINTERFACE']._serialized_start=1400
  _globals['_PUBLICSUBNETNETWORKINTERFACE']._serialized_end=1456
  _globals['_OSSETTINGS']._serialized_start=1458
  _globals['_OSSETTINGS']._serialized_end=1571
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import yandex.cloud.searchapi.v2.search_query_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ImageSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ImageFormat:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ImageFormatEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ImageSpec._ImageFormat.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        IMAGE_FORMAT_UNSPECIFIED: ImageSpec._ImageFormat.ValueType  # 0
        IMAGE_FORMAT_JPEG: ImageSpec._ImageFormat.ValueType  # 1
        """JPG format."""
        IMAGE_FORMAT_GIF: ImageSpec._ImageFormat.ValueType  # 2
        """GIF format."""
        IMAGE_FORMAT_PNG: ImageSpec._ImageFormat.ValueType  # 3
        """PNG format."""

    class ImageFormat(_ImageFormat, metaclass=_ImageFormatEnumTypeWrapper): ...
    IMAGE_FORMAT_UNSPECIFIED: ImageSpec.ImageFormat.ValueType  # 0
    IMAGE_FORMAT_JPEG: ImageSpec.ImageFormat.ValueType  # 1
    """JPG format."""
    IMAGE_FORMAT_GIF: ImageSpec.ImageFormat.ValueType  # 2
    """GIF format."""
    IMAGE_FORMAT_PNG: ImageSpec.ImageFormat.ValueType  # 3
    """PNG format."""

    class _ImageOrientation:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ImageOrientationEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ImageSpec._ImageOrientation.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        IMAGE_ORIENTATION_UNSPECIFIED: ImageSpec._ImageOrientation.ValueType  # 0
        IMAGE_ORIENTATION_VERTICAL: ImageSpec._ImageOrientation.ValueType  # 1
        """Horizontal orientation."""
        IMAGE_ORIENTATION_HORIZONTAL: ImageSpec._ImageOrientation.ValueType  # 2
        """Vertical orientation."""
        IMAGE_ORIENTATION_SQUARE: ImageSpec._ImageOrientation.ValueType  # 3
        """Square aspect ratio."""

    class ImageOrientation(_ImageOrientation, metaclass=_ImageOrientationEnumTypeWrapper): ...
    IMAGE_ORIENTATION_UNSPECIFIED: ImageSpec.ImageOrientation.ValueType  # 0
    IMAGE_ORIENTATION_VERTICAL: ImageSpec.ImageOrientation.ValueType  # 1
    """Horizontal orientation."""
    IMAGE_ORIENTATION_HORIZONTAL: ImageSpec.ImageOrientation.ValueType  # 2
    """Vertical orientation."""
    IMAGE_ORIENTATION_SQUARE: ImageSpec.ImageOrientation.ValueType  # 3
    """Square aspect ratio."""

    class _ImageSize:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ImageSizeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ImageSpec._ImageSize.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        IMAGE_SIZE_UNSPECIFIED: ImageSpec._ImageSize.ValueType  # 0
        IMAGE_SIZE_ENORMOUS: ImageSpec._ImageSize.ValueType  # 1
        """Very large images (larger than 1,600 × 1,200 pixels)."""
        IMAGE_SIZE_LARGE: ImageSpec._ImageSize.ValueType  # 2
        """Large images (from 800 × 600 to 1,600 × 1,200 pixels)."""
        IMAGE_SIZE_MEDIUM: ImageSpec._ImageSize.ValueType  # 3
        """Medium images (from 150 × 150 to 800 × 600 pixels)."""
        IMAGE_SIZE_SMALL: ImageSpec._ImageSize.ValueType  # 4
        """Small images (from 32 × 32 to 150 × 150 pixels)."""
        IMAGE_SIZE_TINY: ImageSpec._ImageSize.ValueType  # 5
        """Icons (up to 32 × 32 pixels)."""
        IMAGE_SIZE_WALLPAPER: ImageSpec._ImageSize.ValueType  # 6
        """Desktop wallpapers."""

    class ImageSize(_ImageSize, metaclass=_ImageSizeEnumTypeWrapper): ...
    IMAGE_SIZE_UNSPECIFIED: ImageSpec.ImageSize.ValueType  # 0
    IMAGE_SIZE_ENORMOUS: ImageSpec.ImageSize.ValueType  # 1
    """Very large images (larger than 1,600 × 1,200 pixels)."""
    IMAGE_SIZE_LARGE: ImageSpec.ImageSize.ValueType  # 2
    """Large images (from 800 × 600 to 1,600 × 1,200 pixels)."""
    IMAGE_SIZE_MEDIUM: ImageSpec.ImageSize.ValueType  # 3
    """Medium images (from 150 × 150 to 800 × 600 pixels)."""
    IMAGE_SIZE_SMALL: ImageSpec.ImageSize.ValueType  # 4
    """Small images (from 32 × 32 to 150 × 150 pixels)."""
    IMAGE_SIZE_TINY: ImageSpec.ImageSize.ValueType  # 5
    """Icons (up to 32 × 32 pixels)."""
    IMAGE_SIZE_WALLPAPER: ImageSpec.ImageSize.ValueType  # 6
    """Desktop wallpapers."""

    class _ImageColor:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ImageColorEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ImageSpec._ImageColor.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        IMAGE_COLOR_UNSPECIFIED: ImageSpec._ImageColor.ValueType  # 0
        IMAGE_COLOR_COLOR: ImageSpec._ImageColor.ValueType  # 1
        """Color images."""
        IMAGE_COLOR_GRAYSCALE: ImageSpec._ImageColor.ValueType  # 2
        """Black and white images."""
        IMAGE_COLOR_RED: ImageSpec._ImageColor.ValueType  # 3
        """Red is the main color of the image."""
        IMAGE_COLOR_ORANGE: ImageSpec._ImageColor.ValueType  # 4
        """Orange is the main color of the image."""
        IMAGE_COLOR_YELLOW: ImageSpec._ImageColor.ValueType  # 5
        """Yellow is the main color of the image."""
        IMAGE_COLOR_GREEN: ImageSpec._ImageColor.ValueType  # 6
        """Green is the main color of the image."""
        IMAGE_COLOR_CYAN: ImageSpec._ImageColor.ValueType  # 7
        """Cyan is the main color of the image."""
        IMAGE_COLOR_BLUE: ImageSpec._ImageColor.ValueType  # 8
        """Blue is the main color of the image."""
        IMAGE_COLOR_VIOLET: ImageSpec._ImageColor.ValueType  # 9
        """Violet is the main color of the image."""
        IMAGE_COLOR_WHITE: ImageSpec._ImageColor.ValueType  # 10
        """White is the main color of the image."""
        IMAGE_COLOR_BLACK: ImageSpec._ImageColor.ValueType  # 11
        """Black is the main color of the image."""

    class ImageColor(_ImageColor, metaclass=_ImageColorEnumTypeWrapper): ...
    IMAGE_COLOR_UNSPECIFIED: ImageSpec.ImageColor.ValueType  # 0
    IMAGE_COLOR_COLOR: ImageSpec.ImageColor.ValueType  # 1
    """Color images."""
    IMAGE_COLOR_GRAYSCALE: ImageSpec.ImageColor.ValueType  # 2
    """Black and white images."""
    IMAGE_COLOR_RED: ImageSpec.ImageColor.ValueType  # 3
    """Red is the main color of the image."""
    IMAGE_COLOR_ORANGE: ImageSpec.ImageColor.ValueType  # 4
    """Orange is the main color of the image."""
    IMAGE_COLOR_YELLOW: ImageSpec.ImageColor.ValueType  # 5
    """Yellow is the main color of the image."""
    IMAGE_COLOR_GREEN: ImageSpec.ImageColor.ValueType  # 6
    """Green is the main color of the image."""
    IMAGE_COLOR_CYAN: ImageSpec.ImageColor.ValueType  # 7
    """Cyan is the main color of the image."""
    IMAGE_COLOR_BLUE: ImageSpec.ImageColor.ValueType  # 8
    """Blue is the main color of the image."""
    IMAGE_COLOR_VIOLET: ImageSpec.ImageColor.ValueType  # 9
    """Violet is the main color of the image."""
    IMAGE_COLOR_WHITE: ImageSpec.ImageColor.ValueType  # 10
    """White is the main color of the image."""
    IMAGE_COLOR_BLACK: ImageSpec.ImageColor.ValueType  # 11
    """Black is the main color of the image."""

    FORMAT_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    ORIENTATION_FIELD_NUMBER: builtins.int
    COLOR_FIELD_NUMBER: builtins.int
    format: global___ImageSpec.ImageFormat.ValueType
    """Searching for images in a particular format."""
    size: global___ImageSpec.ImageSize.ValueType
    """Searching for images of a particular size."""
    orientation: global___ImageSpec.ImageOrientation.ValueType
    """Searching for images with a particular orientation."""
    color: global___ImageSpec.ImageColor.ValueType
    """Searching for images containing a particular color."""
    def __init__(
        self,
        *,
        format: global___ImageSpec.ImageFormat.ValueType = ...,
        size: global___ImageSpec.ImageSize.ValueType = ...,
        orientation: global___ImageSpec.ImageOrientation.ValueType = ...,
        color: global___ImageSpec.ImageColor.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["color", b"color", "format", b"format", "orientation", b"orientation", "size", b"size"]) -> None: ...

global___ImageSpec = ImageSpec

@typing.final
class ImageSearchRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUERY_FIELD_NUMBER: builtins.int
    IMAGE_SPEC_FIELD_NUMBER: builtins.int
    SITE_FIELD_NUMBER: builtins.int
    DOCS_ON_PAGE_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    USER_AGENT_FIELD_NUMBER: builtins.int
    site: builtins.str
    """Searching for images on a particular website only."""
    docs_on_page: builtins.int
    """Number of results per search result page."""
    folder_id: builtins.str
    """ID of the folder."""
    user_agent: builtins.str
    """User-Agent request header value."""
    @property
    def query(self) -> yandex.cloud.searchapi.v2.search_query_pb2.SearchQuery:
        """Search query."""

    @property
    def image_spec(self) -> global___ImageSpec:
        """Searching for images with a particular size, orientation, format or color."""

    def __init__(
        self,
        *,
        query: yandex.cloud.searchapi.v2.search_query_pb2.SearchQuery | None = ...,
        image_spec: global___ImageSpec | None = ...,
        site: builtins.str = ...,
        docs_on_page: builtins.int = ...,
        folder_id: builtins.str = ...,
        user_agent: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["image_spec", b"image_spec", "query", b"query"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["docs_on_page", b"docs_on_page", "folder_id", b"folder_id", "image_spec", b"image_spec", "query", b"query", "site", b"site", "user_agent", b"user_agent"]) -> None: ...

global___ImageSearchRequest = ImageSearchRequest

@typing.final
class ImageSearchResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RAW_DATA_FIELD_NUMBER: builtins.int
    raw_data: builtins.bytes
    """Search results in XML format."""
    def __init__(
        self,
        *,
        raw_data: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["raw_data", b"raw_data"]) -> None: ...

global___ImageSearchResponse = ImageSearchResponse

@typing.final
class ImageSearchByImageRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SITE_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    FAMILY_MODE_FIELD_NUMBER: builtins.int
    site: builtins.str
    """Restricts the search to the specific website."""
    folder_id: builtins.str
    """ID of the folder."""
    url: builtins.str
    """The image url to use for the search."""
    data: builtins.bytes
    """The image data to use for the search."""
    id: builtins.str
    """CBIR ID of the image to use for the search."""
    page: builtins.int
    """The number of a requested page with search results."""
    family_mode: yandex.cloud.searchapi.v2.search_query_pb2.SearchQuery.FamilyMode.ValueType
    """Rule for filtering search results and determines whether any documents should be excluded."""
    def __init__(
        self,
        *,
        site: builtins.str = ...,
        folder_id: builtins.str = ...,
        url: builtins.str = ...,
        data: builtins.bytes = ...,
        id: builtins.str = ...,
        page: builtins.int = ...,
        family_mode: yandex.cloud.searchapi.v2.search_query_pb2.SearchQuery.FamilyMode.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "id", b"id", "image", b"image", "url", b"url"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "family_mode", b"family_mode", "folder_id", b"folder_id", "id", b"id", "image", b"image", "page", b"page", "site", b"site", "url", b"url"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["image", b"image"]) -> typing.Literal["url", "data", "id"] | None: ...

global___ImageSearchByImageRequest = ImageSearchByImageRequest

@typing.final
class ImageSearchByImageResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class ImageInfo(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        URL_FIELD_NUMBER: builtins.int
        FORMAT_FIELD_NUMBER: builtins.int
        WIDTH_FIELD_NUMBER: builtins.int
        HEIGHT_FIELD_NUMBER: builtins.int
        PASSAGE_FIELD_NUMBER: builtins.int
        HOST_FIELD_NUMBER: builtins.int
        PAGE_TITLE_FIELD_NUMBER: builtins.int
        PAGE_URL_FIELD_NUMBER: builtins.int
        url: builtins.str
        """Image URL."""
        format: global___ImageSpec.ImageFormat.ValueType
        """Image format."""
        width: builtins.int
        """Image width."""
        height: builtins.int
        """Image height."""
        passage: builtins.str
        """Text passage."""
        host: builtins.str
        """Document host."""
        page_title: builtins.str
        """Document title."""
        page_url: builtins.str
        """Document URL."""
        def __init__(
            self,
            *,
            url: builtins.str = ...,
            format: global___ImageSpec.ImageFormat.ValueType = ...,
            width: builtins.int = ...,
            height: builtins.int = ...,
            passage: builtins.str = ...,
            host: builtins.str = ...,
            page_title: builtins.str = ...,
            page_url: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["format", b"format", "height", b"height", "host", b"host", "page_title", b"page_title", "page_url", b"page_url", "passage", b"passage", "url", b"url", "width", b"width"]) -> None: ...

    IMAGES_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    MAX_PAGE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    page: builtins.int
    """The number of the page with search results."""
    max_page: builtins.int
    """The number of the last page with search results."""
    id: builtins.str
    """CBIR ID of the image used for the search."""
    @property
    def images(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ImageSearchByImageResponse.ImageInfo]:
        """The images found."""

    def __init__(
        self,
        *,
        images: collections.abc.Iterable[global___ImageSearchByImageResponse.ImageInfo] | None = ...,
        page: builtins.int = ...,
        max_page: builtins.int = ...,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "images", b"images", "max_page", b"max_page", "page", b"page"]) -> None: ...

global___ImageSearchByImageResponse = ImageSearchByImageResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.logging.v1.sink_pb2
import yandex.cloud.operation.operation_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetSinkRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SINK_ID_FIELD_NUMBER: builtins.int
    sink_id: builtins.str
    """ID of the sink to return.

    To get a sink ID make a [SinkService.List] request.
    """
    def __init__(
        self,
        *,
        sink_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["sink_id", b"sink_id"]) -> None: ...

global___GetSinkRequest = GetSinkRequest

@typing.final
class ListSinksRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """Folder ID of the sinks to return.

    To get a folder ID make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than `page_size`, the service returns a [ListSinkssResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.

    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListSinksResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters sinks listed in the response.

    The expression must specify:
    1. The field name. Currently filtering can only be applied to the [Sink.name] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    Example of a filter: `name="my-sink"`.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListSinksRequest = ListSinksRequest

@typing.final
class ListSinksResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SINKS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListSinksRequest.page_size], use `next_page_token` as the value
    for the [ListSinksRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def sinks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.logging.v1.sink_pb2.Sink]:
        """List of sinks in the specified folder."""

    def __init__(
        self,
        *,
        sinks: collections.abc.Iterable[yandex.cloud.logging.v1.sink_pb2.Sink] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "sinks", b"sinks"]) -> None: ...

global___ListSinksResponse = ListSinksResponse

@typing.final
class CreateSinkRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    YDS_FIELD_NUMBER: builtins.int
    S3_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create a sink in.

    To get a folder ID make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    name: builtins.str
    """Name of the sink.
    The name must be unique within the folder.
    """
    description: builtins.str
    """Description of the sink."""
    service_account_id: builtins.str
    """Logs will be written to the sink on behalf of this service account"""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Sink labels as `key:value` pairs."""

    @property
    def yds(self) -> yandex.cloud.logging.v1.sink_pb2.Sink.Yds:
        """Yandex data stream"""

    @property
    def s3(self) -> yandex.cloud.logging.v1.sink_pb2.Sink.S3:
        """Object storage"""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        service_account_id: builtins.str = ...,
        yds: yandex.cloud.logging.v1.sink_pb2.Sink.Yds | None = ...,
        s3: yandex.cloud.logging.v1.sink_pb2.Sink.S3 | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["s3", b"s3", "sink", b"sink", "yds", b"yds"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "folder_id", b"folder_id", "labels", b"labels", "name", b"name", "s3", b"s3", "service_account_id", b"service_account_id", "sink", b"sink", "yds", b"yds"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["sink", b"sink"]) -> typing.Literal["yds", "s3"] | None: ...

global___CreateSinkRequest = CreateSinkRequest

@typing.final
class CreateSinkMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SINK_ID_FIELD_NUMBER: builtins.int
    sink_id: builtins.str
    """ID of the sink being created."""
    def __init__(
        self,
        *,
        sink_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["sink_id", b"sink_id"]) -> None: ...

global___CreateSinkMetadata = CreateSinkMetadata

@typing.final
class UpdateSinkRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    SINK_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    YDS_FIELD_NUMBER: builtins.int
    S3_FIELD_NUMBER: builtins.int
    sink_id: builtins.str
    """ID of the sink to update.

    To get a sink ID make a [SinkService.List] request.
    """
    name: builtins.str
    """New name of the sink.
    The name must be unique within the folder.
    """
    description: builtins.str
    """New Description of the sink."""
    service_account_id: builtins.str
    """new service account to use for logs writing to the sink."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which attributes of the function should be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """New sink labels as `key:value` pairs."""

    @property
    def yds(self) -> yandex.cloud.logging.v1.sink_pb2.Sink.Yds:
        """Yandex data stream"""

    @property
    def s3(self) -> yandex.cloud.logging.v1.sink_pb2.Sink.S3:
        """Object storage"""

    def __init__(
        self,
        *,
        sink_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        service_account_id: builtins.str = ...,
        yds: yandex.cloud.logging.v1.sink_pb2.Sink.Yds | None = ...,
        s3: yandex.cloud.logging.v1.sink_pb2.Sink.S3 | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["s3", b"s3", "sink", b"sink", "update_mask", b"update_mask", "yds", b"yds"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "labels", b"labels", "name", b"name", "s3", b"s3", "service_account_id", b"service_account_id", "sink", b"sink", "sink_id", b"sink_id", "update_mask", b"update_mask", "yds", b"yds"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["sink", b"sink"]) -> typing.Literal["yds", "s3"] | None: ...

global___UpdateSinkRequest = UpdateSinkRequest

@typing.final
class UpdateSinkMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SINK_ID_FIELD_NUMBER: builtins.int
    sink_id: builtins.str
    """ID of the sink being updated."""
    def __init__(
        self,
        *,
        sink_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["sink_id", b"sink_id"]) -> None: ...

global___UpdateSinkMetadata = UpdateSinkMetadata

@typing.final
class DeleteSinkRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SINK_ID_FIELD_NUMBER: builtins.int
    sink_id: builtins.str
    """ID of the sink to delete.

    To get a sink ID make a [SinkService.List] request.
    """
    def __init__(
        self,
        *,
        sink_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["sink_id", b"sink_id"]) -> None: ...

global___DeleteSinkRequest = DeleteSinkRequest

@typing.final
class DeleteSinkMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SINK_ID_FIELD_NUMBER: builtins.int
    sink_id: builtins.str
    """ID of the sink being deleted."""
    def __init__(
        self,
        *,
        sink_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["sink_id", b"sink_id"]) -> None: ...

global___DeleteSinkMetadata = DeleteSinkMetadata

@typing.final
class ListSinkOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SINK_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    sink_id: builtins.str
    """ID of the sink to list operations for.

    To get a sink ID make a [SinkService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than `page_size`, the service returns a [ListSinkOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.

    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListSinkOperationsResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.

    The expression must specify:
    1. The field name. Currently filtering can be applied to the [operation.Operation.description], [operation.Operation.created_at], [operation.Operation.modified_at], [operation.Operation.created_by], [operation.Operation.done] fields.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    Examples of a filter: `done=false`, `created_by='John.Doe'`.
    """
    def __init__(
        self,
        *,
        sink_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "page_size", b"page_size", "page_token", b"page_token", "sink_id", b"sink_id"]) -> None: ...

global___ListSinkOperationsRequest = ListSinkOperationsRequest

@typing.final
class ListSinkOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    the specified [ListOSinkperationsRequest.page_size], use `next_page_token` as the value
    for the [ListSinkOperationsRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified sink."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListSinkOperationsResponse = ListSinkOperationsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import yandex.cloud.connectionmanager.v1.connection_pb2
import yandex.cloud.operation.operation_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CreateConnectionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    PARAMS_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    name: builtins.str
    description: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def params(self) -> yandex.cloud.connectionmanager.v1.connection_pb2.ConnectionParams: ...
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        params: yandex.cloud.connectionmanager.v1.connection_pb2.ConnectionParams | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["params", b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "folder_id", b"folder_id", "labels", b"labels", "name", b"name", "params", b"params"]) -> None: ...

global___CreateConnectionRequest = CreateConnectionRequest

@typing.final
class CreateConnectionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTION_ID_FIELD_NUMBER: builtins.int
    connection_id: builtins.str
    def __init__(
        self,
        *,
        connection_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["connection_id", b"connection_id"]) -> None: ...

global___CreateConnectionMetadata = CreateConnectionMetadata

@typing.final
class UpdateConnectionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    CONNECTION_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    PARAMS_FIELD_NUMBER: builtins.int
    connection_id: builtins.str
    name: builtins.str
    description: builtins.str
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask: ...
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def params(self) -> yandex.cloud.connectionmanager.v1.connection_pb2.ConnectionParams: ...
    def __init__(
        self,
        *,
        connection_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        params: yandex.cloud.connectionmanager.v1.connection_pb2.ConnectionParams | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["params", b"params", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["connection_id", b"connection_id", "description", b"description", "labels", b"labels", "name", b"name", "params", b"params", "update_mask", b"update_mask"]) -> None: ...

global___UpdateConnectionRequest = UpdateConnectionRequest

@typing.final
class UpdateConnectionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTION_ID_FIELD_NUMBER: builtins.int
    connection_id: builtins.str
    def __init__(
        self,
        *,
        connection_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["connection_id", b"connection_id"]) -> None: ...

global___UpdateConnectionMetadata = UpdateConnectionMetadata

@typing.final
class DeleteConnectionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTION_ID_FIELD_NUMBER: builtins.int
    connection_id: builtins.str
    def __init__(
        self,
        *,
        connection_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["connection_id", b"connection_id"]) -> None: ...

global___DeleteConnectionRequest = DeleteConnectionRequest

@typing.final
class DeleteConnectionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteConnectionMetadata = DeleteConnectionMetadata

@typing.final
class ListConnectionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    MDB_CLUSTER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    NAME_PATTERN_OR_ID_FIELD_NUMBER: builtins.int
    AUTHOR_ID_FIELD_NUMBER: builtins.int
    WITH_CAN_USE_FIELD_NUMBER: builtins.int
    IS_ONPREMISE_FIELD_NUMBER: builtins.int
    IS_MANUAL_FIELD_NUMBER: builtins.int
    DB_TYPE_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    mdb_cluster_id: builtins.str
    page_size: builtins.int
    page_token: builtins.str
    name_pattern_or_id: builtins.str
    author_id: builtins.str
    with_can_use: builtins.bool
    db_type: yandex.cloud.connectionmanager.v1.connection_pb2.DBType.ValueType
    @property
    def is_onpremise(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def is_manual(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        mdb_cluster_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        name_pattern_or_id: builtins.str = ...,
        author_id: builtins.str = ...,
        with_can_use: builtins.bool = ...,
        is_onpremise: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        is_manual: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        db_type: yandex.cloud.connectionmanager.v1.connection_pb2.DBType.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["is_manual", b"is_manual", "is_onpremise", b"is_onpremise"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["author_id", b"author_id", "db_type", b"db_type", "folder_id", b"folder_id", "is_manual", b"is_manual", "is_onpremise", b"is_onpremise", "mdb_cluster_id", b"mdb_cluster_id", "name_pattern_or_id", b"name_pattern_or_id", "page_size", b"page_size", "page_token", b"page_token", "with_can_use", b"with_can_use"]) -> None: ...

global___ListConnectionRequest = ListConnectionRequest

@typing.final
class ListConnectionResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTION_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    @property
    def connection(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.connectionmanager.v1.connection_pb2.Connection]: ...
    def __init__(
        self,
        *,
        connection: collections.abc.Iterable[yandex.cloud.connectionmanager.v1.connection_pb2.Connection] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["connection", b"connection", "next_page_token", b"next_page_token"]) -> None: ...

global___ListConnectionResponse = ListConnectionResponse

@typing.final
class GetConnectionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTION_ID_FIELD_NUMBER: builtins.int
    connection_id: builtins.str
    def __init__(
        self,
        *,
        connection_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["connection_id", b"connection_id"]) -> None: ...

global___GetConnectionRequest = GetConnectionRequest

@typing.final
class ResolveClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTION_ID_FIELD_NUMBER: builtins.int
    connection_id: builtins.str
    def __init__(
        self,
        *,
        connection_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["connection_id", b"connection_id"]) -> None: ...

global___ResolveClusterRequest = ResolveClusterRequest

@typing.final
class DeleteVersionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTION_ID_FIELD_NUMBER: builtins.int
    VERSION_ID_FIELD_NUMBER: builtins.int
    connection_id: builtins.str
    version_id: builtins.str
    def __init__(
        self,
        *,
        connection_id: builtins.str = ...,
        version_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["connection_id", b"connection_id", "version_id", b"version_id"]) -> None: ...

global___DeleteVersionMetadata = DeleteVersionMetadata

@typing.final
class ListOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTION_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    connection_id: builtins.str
    page_size: builtins.int
    page_token: builtins.str
    def __init__(
        self,
        *,
        connection_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["connection_id", b"connection_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListOperationsRequest = ListOperationsRequest

@typing.final
class ListOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]: ...
    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListOperationsResponse = ListOperationsResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/serverless/workflows/v1/workflow_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/serverless/workflows/v1/workflow_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.serverless.workflows.v1 import workflow_pb2 as yandex_dot_cloud_dot_serverless_dot_workflows_dot_v1_dot_workflow__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;yandex/cloud/serverless/workflows/v1/workflow_service.proto\x12$yandex.cloud.serverless.workflows.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x33yandex/cloud/serverless/workflows/v1/workflow.proto\x1a\x1dyandex/cloud/validation.proto\"\x82\x05\n\x15\x43reateWorkflowRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x36\n\x04name\x18\x02 \x01(\tB(\xe8\xc7\x31\x01\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x9c\x01\n\x06labels\x18\x04 \x03(\x0b\x32G.yandex.cloud.serverless.workflows.v1.CreateWorkflowRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12X\n\rspecification\x18\x05 \x01(\x0b\x32;.yandex.cloud.serverless.workflows.v1.WorkflowSpecificationB\x04\xe8\xc7\x31\x01\x12\x45\n\x0blog_options\x18\x06 \x01(\x0b\x32\x30.yandex.cloud.serverless.workflows.v1.LogOptions\x12\x12\n\nnetwork_id\x18\x07 \x01(\t\x12\x1a\n\x12service_account_id\x18\x08 \x01(\t\x12\x0f\n\x07\x65xpress\x18\t \x01(\x08\x12H\n\x08schedule\x18\n \x01(\x0b\x32\x36.yandex.cloud.serverless.workflows.v1.WorkflowSchedule\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"3\n\x16\x43reateWorkflowMetadata\x12\x19\n\x0bworkflow_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\xab\x05\n\x15UpdateWorkflowRequest\x12\x19\n\x0bworkflow_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x32\n\x04name\x18\x02 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x9c\x01\n\x06labels\x18\x04 \x03(\x0b\x32G.yandex.cloud.serverless.workflows.v1.UpdateWorkflowRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12R\n\rspecification\x18\x05 \x01(\x0b\x32;.yandex.cloud.serverless.workflows.v1.WorkflowSpecification\x12\x45\n\x0blog_options\x18\x06 \x01(\x0b\x32\x30.yandex.cloud.serverless.workflows.v1.LogOptions\x12\x12\n\nnetwork_id\x18\x07 \x01(\t\x12\x1a\n\x12service_account_id\x18\x08 \x01(\t\x12/\n\x0bupdate_mask\x18\t \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x0f\n\x07\x65xpress\x18\n \x01(\x08\x12H\n\x08schedule\x18\x0b \x01(\x0b\x32\x36.yandex.cloud.serverless.workflows.v1.WorkflowSchedule\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"3\n\x16UpdateWorkflowMetadata\x12\x19\n\x0bworkflow_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"/\n\x12GetWorkflowRequest\x12\x19\n\x0bworkflow_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"W\n\x13GetWorkflowResponse\x12@\n\x08workflow\x18\x01 \x01(\x0b\x32..yandex.cloud.serverless.workflows.v1.Workflow\"2\n\x15\x44\x65leteWorkflowRequest\x12\x19\n\x0bworkflow_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"-\n\x16\x44\x65leteWorkflowMetadata\x12\x13\n\x0bworkflow_id\x18\x01 \x01(\t\"f\n\x14ListWorkflowsRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x04 \x01(\t\"z\n\x15ListWorkflowsResponse\x12H\n\tworkflows\x18\x01 \x03(\x0b\x32\x35.yandex.cloud.serverless.workflows.v1.WorkflowPreview\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x8c\x01\n\x15ListOperationsRequest\x12\x19\n\x0bworkflow_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"h\n\x16ListOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xe7\x08\n\x0fWorkflowService\x12\xb1\x01\n\x06\x43reate\x12;.yandex.cloud.serverless.workflows.v1.CreateWorkflowRequest\x1a!.yandex.cloud.operation.Operation\"G\xb2\xd2*\"\n\x16\x43reateWorkflowMetadata\x12\x08Workflow\x82\xd3\xe4\x93\x02\x1b\"\x16/workflows/v1/workflow:\x01*\x12\xbf\x01\n\x06Update\x12;.yandex.cloud.serverless.workflows.v1.UpdateWorkflowRequest\x1a!.yandex.cloud.operation.Operation\"U\xb2\xd2*\"\n\x16UpdateWorkflowMetadata\x12\x08Workflow\x82\xd3\xe4\x93\x02)2$/workflows/v1/workflow/{workflow_id}:\x01*\x12\xa8\x01\n\x03Get\x12\x38.yandex.cloud.serverless.workflows.v1.GetWorkflowRequest\x1a\x39.yandex.cloud.serverless.workflows.v1.GetWorkflowResponse\",\x82\xd3\xe4\x93\x02&\x12$/workflows/v1/workflow/{workflow_id}\x12\xc9\x01\n\x06\x44\x65lete\x12;.yandex.cloud.serverless.workflows.v1.DeleteWorkflowRequest\x1a!.yandex.cloud.operation.Operation\"_\xb2\xd2*/\n\x16\x44\x65leteWorkflowMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02&*$/workflows/v1/workflow/{workflow_id}\x12\x9f\x01\n\x04List\x12:.yandex.cloud.serverless.workflows.v1.ListWorkflowsRequest\x1a;.yandex.cloud.serverless.workflows.v1.ListWorkflowsResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/workflows/v1/workflow\x12\xc4\x01\n\x0eListOperations\x12;.yandex.cloud.serverless.workflows.v1.ListOperationsRequest\x1a<.yandex.cloud.serverless.workflows.v1.ListOperationsResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//workflows/v1/workflow/{workflow_id}/operationsB~\n(yandex.cloud.api.serverless.workflows.v1ZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/workflows/v1;workflowsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.serverless.workflows.v1.workflow_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(yandex.cloud.api.serverless.workflows.v1ZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/workflows/v1;workflows'
  _globals['_CREATEWORKFLOWREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATEWORKFLOWREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEWORKFLOWREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATEWORKFLOWREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_CREATEWORKFLOWREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEWORKFLOWREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _globals['_CREATEWORKFLOWREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATEWORKFLOWREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_CREATEWORKFLOWREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATEWORKFLOWREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _globals['_CREATEWORKFLOWREQUEST'].fields_by_name['specification']._loaded_options = None
  _globals['_CREATEWORKFLOWREQUEST'].fields_by_name['specification']._serialized_options = b'\350\3071\001'
  _globals['_CREATEWORKFLOWMETADATA'].fields_by_name['workflow_id']._loaded_options = None
  _globals['_CREATEWORKFLOWMETADATA'].fields_by_name['workflow_id']._serialized_options = b'\350\3071\001'
  _globals['_UPDATEWORKFLOWREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATEWORKFLOWREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEWORKFLOWREQUEST'].fields_by_name['workflow_id']._loaded_options = None
  _globals['_UPDATEWORKFLOWREQUEST'].fields_by_name['workflow_id']._serialized_options = b'\350\3071\001'
  _globals['_UPDATEWORKFLOWREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEWORKFLOWREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _globals['_UPDATEWORKFLOWREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATEWORKFLOWREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATEWORKFLOWREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATEWORKFLOWREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _globals['_UPDATEWORKFLOWMETADATA'].fields_by_name['workflow_id']._loaded_options = None
  _globals['_UPDATEWORKFLOWMETADATA'].fields_by_name['workflow_id']._serialized_options = b'\350\3071\001'
  _globals['_GETWORKFLOWREQUEST'].fields_by_name['workflow_id']._loaded_options = None
  _globals['_GETWORKFLOWREQUEST'].fields_by_name['workflow_id']._serialized_options = b'\350\3071\001'
  _globals['_DELETEWORKFLOWREQUEST'].fields_by_name['workflow_id']._loaded_options = None
  _globals['_DELETEWORKFLOWREQUEST'].fields_by_name['workflow_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTWORKFLOWSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTWORKFLOWSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTOPERATIONSREQUEST'].fields_by_name['workflow_id']._loaded_options = None
  _globals['_LISTOPERATIONSREQUEST'].fields_by_name['workflow_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTOPERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTOPERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTOPERATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTOPERATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTOPERATIONSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTOPERATIONSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_WORKFLOWSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_WORKFLOWSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*\"\n\026CreateWorkflowMetadata\022\010Workflow\202\323\344\223\002\033\"\026/workflows/v1/workflow:\001*'
  _globals['_WORKFLOWSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_WORKFLOWSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*\"\n\026UpdateWorkflowMetadata\022\010Workflow\202\323\344\223\002)2$/workflows/v1/workflow/{workflow_id}:\001*'
  _globals['_WORKFLOWSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_WORKFLOWSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002&\022$/workflows/v1/workflow/{workflow_id}'
  _globals['_WORKFLOWSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_WORKFLOWSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*/\n\026DeleteWorkflowMetadata\022\025google.protobuf.Empty\202\323\344\223\002&*$/workflows/v1/workflow/{workflow_id}'
  _globals['_WORKFLOWSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_WORKFLOWSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\030\022\026/workflows/v1/workflow'
  _globals['_WORKFLOWSERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_WORKFLOWSERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\0021\022//workflows/v1/workflow/{workflow_id}/operations'
  _globals['_CREATEWORKFLOWREQUEST']._serialized_start=324
  _globals['_CREATEWORKFLOWREQUEST']._serialized_end=966
  _globals['_CREATEWORKFLOWREQUEST_LABELSENTRY']._serialized_start=921
  _globals['_CREATEWORKFLOWREQUEST_LABELSENTRY']._serialized_end=966
  _globals['_CREATEWORKFLOWMETADATA']._serialized_start=968
  _globals['_CREATEWORKFLOWMETADATA']._serialized_end=1019
  _globals['_UPDATEWORKFLOWREQUEST']._serialized_start=1022
  _globals['_UPDATEWORKFLOWREQUEST']._serialized_end=1705
  _globals['_UPDATEWORKFLOWREQUEST_LABELSENTRY']._serialized_start=921
  _globals['_UPDATEWORKFLOWREQUEST_LABELSENTRY']._serialized_end=966
  _globals['_UPDATEWORKFLOWMETADATA']._serialized_start=1707
  _globals['_UPDATEWORKFLOWMETADATA']._serialized_end=1758
  _globals['_GETWORKFLOWREQUEST']._serialized_start=1760
  _globals['_GETWORKFLOWREQUEST']._serialized_end=1807
  _globals['_GETWORKFLOWRESPONSE']._serialized_start=1809
  _globals['_GETWORKFLOWRESPONSE']._serialized_end=1896
  _globals['_DELETEWORKFLOWREQUEST']._serialized_start=1898
  _globals['_DELETEWORKFLOWREQUEST']._serialized_end=1948
  _globals['_DELETEWORKFLOWMETADATA']._serialized_start=1950
  _globals['_DELETEWORKFLOWMETADATA']._serialized_end=1995
  _globals['_LISTWORKFLOWSREQUEST']._serialized_start=1997
  _globals['_LISTWORKFLOWSREQUEST']._serialized_end=2099
  _globals['_LISTWORKFLOWSRESPONSE']._serialized_start=2101
  _globals['_LISTWORKFLOWSRESPONSE']._serialized_end=2223
  _globals['_LISTOPERATIONSREQUEST']._serialized_start=2226
  _globals['_LISTOPERATIONSREQUEST']._serialized_end=2366
  _globals['_LISTOPERATIONSRESPONSE']._serialized_start=2368
  _globals['_LISTOPERATIONSRESPONSE']._serialized_end=2472
  _globals['_WORKFLOWSERVICE']._serialized_start=2475
  _globals['_WORKFLOWSERVICE']._serialized_end=3602
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/containerregistry/v1/registry_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/containerregistry/v1/registry_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.containerregistry.v1 import registry_pb2 as yandex_dot_cloud_dot_containerregistry_dot_v1_dot_registry__pb2
from yandex.cloud.containerregistry.v1 import ip_permission_pb2 as yandex_dot_cloud_dot_containerregistry_dot_v1_dot_ip__permission__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8yandex/cloud/containerregistry/v1/registry_service.proto\x12!yandex.cloud.containerregistry.v1\x1a yandex/cloud/api/operation.proto\x1a yandex/cloud/access/access.proto\x1a\x30yandex/cloud/containerregistry/v1/registry.proto\x1a\x35yandex/cloud/containerregistry/v1/ip_permission.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\"7\n\x12GetRegistryRequest\x12!\n\x0bregistry_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x92\x01\n\x15ListRegistriesRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"r\n\x16ListRegistriesResponse\x12?\n\nregistries\x18\x01 \x03(\x0b\x32+.yandex.cloud.containerregistry.v1.Registry\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xbc\x02\n\x15\x43reateRegistryRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x04name\x18\x02 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x91\x01\n\x06labels\x18\x03 \x03(\x0b\x32\x44.yandex.cloud.containerregistry.v1.CreateRegistryRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12\x0e\n\x06secure\x18\x04 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"-\n\x16\x43reateRegistryMetadata\x12\x13\n\x0bregistry_id\x18\x01 \x01(\t\"\xdf\x02\n\x15UpdateRegistryRequest\x12!\n\x0bregistry_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12/\n\x04name\x18\x03 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x91\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x44.yandex.cloud.containerregistry.v1.UpdateRegistryRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"-\n\x16UpdateRegistryMetadata\x12\x13\n\x0bregistry_id\x18\x01 \x01(\t\":\n\x15\x44\x65leteRegistryRequest\x12!\n\x0bregistry_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"-\n\x16\x44\x65leteRegistryMetadata\x12\x13\n\x0bregistry_id\x18\x01 \x01(\t\"\x83\x01\n\x16SetIpPermissionRequest\x12!\n\x0bregistry_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x46\n\rip_permission\x18\x02 \x03(\x0b\x32/.yandex.cloud.containerregistry.v1.IpPermission\"\x92\x01\n\x19UpdateIpPermissionRequest\x12!\n\x0bregistry_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12R\n\x14ip_permission_deltas\x18\x02 \x03(\x0b\x32\x34.yandex.cloud.containerregistry.v1.IpPermissionDelta\"<\n\x17ListIpPermissionRequest\x12!\n\x0bregistry_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"a\n\x19ListIpPermissionsResponse\x12\x44\n\x0bpermissions\x18\x01 \x03(\x0b\x32/.yandex.cloud.containerregistry.v1.IpPermission\".\n\x17SetIpPermissionMetadata\x12\x13\n\x0bregistry_id\x18\x01 \x01(\t\"1\n\x1aUpdateIpPermissionMetadata\x12\x13\n\x0bregistry_id\x18\x01 \x01(\t2\xbb\x12\n\x0fRegistryService\x12\xa2\x01\n\x03Get\x12\x35.yandex.cloud.containerregistry.v1.GetRegistryRequest\x1a+.yandex.cloud.containerregistry.v1.Registry\"7\x82\xd3\xe4\x93\x02\x31\x12//container-registry/v1/registries/{registry_id}\x12\xa6\x01\n\x04List\x12\x38.yandex.cloud.containerregistry.v1.ListRegistriesRequest\x1a\x39.yandex.cloud.containerregistry.v1.ListRegistriesResponse\")\x82\xd3\xe4\x93\x02#\x12!/container-registry/v1/registries\x12\xb9\x01\n\x06\x43reate\x12\x38.yandex.cloud.containerregistry.v1.CreateRegistryRequest\x1a!.yandex.cloud.operation.Operation\"R\xb2\xd2*\"\n\x16\x43reateRegistryMetadata\x12\x08Registry\x82\xd3\xe4\x93\x02&\"!/container-registry/v1/registries:\x01*\x12\xc7\x01\n\x06Update\x12\x38.yandex.cloud.containerregistry.v1.UpdateRegistryRequest\x1a!.yandex.cloud.operation.Operation\"`\xb2\xd2*\"\n\x16UpdateRegistryMetadata\x12\x08Registry\x82\xd3\xe4\x93\x02\x34\x32//container-registry/v1/registries/{registry_id}:\x01*\x12\xd1\x01\n\x06\x44\x65lete\x12\x38.yandex.cloud.containerregistry.v1.DeleteRegistryRequest\x1a!.yandex.cloud.operation.Operation\"j\xb2\xd2*/\n\x16\x44\x65leteRegistryMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x31*//container-registry/v1/registries/{registry_id}\x12\xc1\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"J\x82\xd3\xe4\x93\x02\x44\x12\x42/container-registry/v1/registries/{resource_id}:listAccessBindings\x12\xf1\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x89\x01\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x46\"A/container-registry/v1/registries/{resource_id}:setAccessBindings:\x01*\x12\xfd\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x8f\x01\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02I\"D/container-registry/v1/registries/{resource_id}:updateAccessBindings:\x01*\x12\xd6\x01\n\x10ListIpPermission\x12:.yandex.cloud.containerregistry.v1.ListIpPermissionRequest\x1a<.yandex.cloud.containerregistry.v1.ListIpPermissionsResponse\"H\x82\xd3\xe4\x93\x02\x42\x12@/container-registry/v1/registries/{registry_id}:listIpPermission\x12\xef\x01\n\x0fSetIpPermission\x12\x39.yandex.cloud.containerregistry.v1.SetIpPermissionRequest\x1a!.yandex.cloud.operation.Operation\"~\xb2\xd2*0\n\x17SetIpPermissionMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x44\"?/container-registry/v1/registries/{registry_id}:setIpPermission:\x01*\x12\xfc\x01\n\x12UpdateIpPermission\x12<.yandex.cloud.containerregistry.v1.UpdateIpPermissionRequest\x1a!.yandex.cloud.operation.Operation\"\x84\x01\xb2\xd2*3\n\x1aUpdateIpPermissionMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02G\"B/container-registry/v1/registries/{registry_id}:updateIpPermission:\x01*B\x80\x01\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistryb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.containerregistry.v1.registry_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistry'
  _globals['_GETREGISTRYREQUEST'].fields_by_name['registry_id']._loaded_options = None
  _globals['_GETREGISTRYREQUEST'].fields_by_name['registry_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTREGISTRIESREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTREGISTRIESREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTREGISTRIESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTREGISTRIESREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTREGISTRIESREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTREGISTRIESREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTREGISTRIESREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTREGISTRIESREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_CREATEREGISTRYREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATEREGISTRYREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEREGISTRYREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATEREGISTRYREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEREGISTRYREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEREGISTRYREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _globals['_CREATEREGISTRYREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATEREGISTRYREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_UPDATEREGISTRYREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATEREGISTRYREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEREGISTRYREQUEST'].fields_by_name['registry_id']._loaded_options = None
  _globals['_UPDATEREGISTRYREQUEST'].fields_by_name['registry_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEREGISTRYREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEREGISTRYREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _globals['_UPDATEREGISTRYREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATEREGISTRYREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_DELETEREGISTRYREQUEST'].fields_by_name['registry_id']._loaded_options = None
  _globals['_DELETEREGISTRYREQUEST'].fields_by_name['registry_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_SETIPPERMISSIONREQUEST'].fields_by_name['registry_id']._loaded_options = None
  _globals['_SETIPPERMISSIONREQUEST'].fields_by_name['registry_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEIPPERMISSIONREQUEST'].fields_by_name['registry_id']._loaded_options = None
  _globals['_UPDATEIPPERMISSIONREQUEST'].fields_by_name['registry_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTIPPERMISSIONREQUEST'].fields_by_name['registry_id']._loaded_options = None
  _globals['_LISTIPPERMISSIONREQUEST'].fields_by_name['registry_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_REGISTRYSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\0021\022//container-registry/v1/registries/{registry_id}'
  _globals['_REGISTRYSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002#\022!/container-registry/v1/registries'
  _globals['_REGISTRYSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*\"\n\026CreateRegistryMetadata\022\010Registry\202\323\344\223\002&\"!/container-registry/v1/registries:\001*'
  _globals['_REGISTRYSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*\"\n\026UpdateRegistryMetadata\022\010Registry\202\323\344\223\00242//container-registry/v1/registries/{registry_id}:\001*'
  _globals['_REGISTRYSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*/\n\026DeleteRegistryMetadata\022\025google.protobuf.Empty\202\323\344\223\0021*//container-registry/v1/registries/{registry_id}'
  _globals['_REGISTRYSERVICE'].methods_by_name['ListAccessBindings']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\002D\022B/container-registry/v1/registries/{resource_id}:listAccessBindings'
  _globals['_REGISTRYSERVICE'].methods_by_name['SetAccessBindings']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002F\"A/container-registry/v1/registries/{resource_id}:setAccessBindings:\001*'
  _globals['_REGISTRYSERVICE'].methods_by_name['UpdateAccessBindings']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002I\"D/container-registry/v1/registries/{resource_id}:updateAccessBindings:\001*'
  _globals['_REGISTRYSERVICE'].methods_by_name['ListIpPermission']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['ListIpPermission']._serialized_options = b'\202\323\344\223\002B\022@/container-registry/v1/registries/{registry_id}:listIpPermission'
  _globals['_REGISTRYSERVICE'].methods_by_name['SetIpPermission']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['SetIpPermission']._serialized_options = b'\262\322*0\n\027SetIpPermissionMetadata\022\025google.protobuf.Empty\202\323\344\223\002D\"?/container-registry/v1/registries/{registry_id}:setIpPermission:\001*'
  _globals['_REGISTRYSERVICE'].methods_by_name['UpdateIpPermission']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['UpdateIpPermission']._serialized_options = b'\262\322*3\n\032UpdateIpPermissionMetadata\022\025google.protobuf.Empty\202\323\344\223\002G\"B/container-registry/v1/registries/{registry_id}:updateIpPermission:\001*'
  _globals['_GETREGISTRYREQUEST']._serialized_start=403
  _globals['_GETREGISTRYREQUEST']._serialized_end=458
  _globals['_LISTREGISTRIESREQUEST']._serialized_start=461
  _globals['_LISTREGISTRIESREQUEST']._serialized_end=607
  _globals['_LISTREGISTRIESRESPONSE']._serialized_start=609
  _globals['_LISTREGISTRIESRESPONSE']._serialized_end=723
  _globals['_CREATEREGISTRYREQUEST']._serialized_start=726
  _globals['_CREATEREGISTRYREQUEST']._serialized_end=1042
  _globals['_CREATEREGISTRYREQUEST_LABELSENTRY']._serialized_start=997
  _globals['_CREATEREGISTRYREQUEST_LABELSENTRY']._serialized_end=1042
  _globals['_CREATEREGISTRYMETADATA']._serialized_start=1044
  _globals['_CREATEREGISTRYMETADATA']._serialized_end=1089
  _globals['_UPDATEREGISTRYREQUEST']._serialized_start=1092
  _globals['_UPDATEREGISTRYREQUEST']._serialized_end=1443
  _globals['_UPDATEREGISTRYREQUEST_LABELSENTRY']._serialized_start=997
  _globals['_UPDATEREGISTRYREQUEST_LABELSENTRY']._serialized_end=1042
  _globals['_UPDATEREGISTRYMETADATA']._serialized_start=1445
  _globals['_UPDATEREGISTRYMETADATA']._serialized_end=1490
  _globals['_DELETEREGISTRYREQUEST']._serialized_start=1492
  _globals['_DELETEREGISTRYREQUEST']._serialized_end=1550
  _globals['_DELETEREGISTRYMETADATA']._serialized_start=1552
  _globals['_DELETEREGISTRYMETADATA']._serialized_end=1597
  _globals['_SETIPPERMISSIONREQUEST']._serialized_start=1600
  _globals['_SETIPPERMISSIONREQUEST']._serialized_end=1731
  _globals['_UPDATEIPPERMISSIONREQUEST']._serialized_start=1734
  _globals['_UPDATEIPPERMISSIONREQUEST']._serialized_end=1880
  _globals['_LISTIPPERMISSIONREQUEST']._serialized_start=1882
  _globals['_LISTIPPERMISSIONREQUEST']._serialized_end=1942
  _globals['_LISTIPPERMISSIONSRESPONSE']._serialized_start=1944
  _globals['_LISTIPPERMISSIONSRESPONSE']._serialized_end=2041
  _globals['_SETIPPERMISSIONMETADATA']._serialized_start=2043
  _globals['_SETIPPERMISSIONMETADATA']._serialized_end=2089
  _globals['_UPDATEIPPERMISSIONMETADATA']._serialized_start=2091
  _globals['_UPDATEIPPERMISSIONMETADATA']._serialized_end=2140
  _globals['_REGISTRYSERVICE']._serialized_start=2143
  _globals['_REGISTRYSERVICE']._serialized_end=4506
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ExtensionType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ExtensionTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ExtensionType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    EXTENSION_TYPE_UNSPECIFIED: _ExtensionType.ValueType  # 0
    EXTENSION_TYPE_SYNONYMS: _ExtensionType.ValueType  # 1
    EXTENSION_TYPE_STOPWORDS: _ExtensionType.ValueType  # 2

class ExtensionType(_ExtensionType, metaclass=_ExtensionTypeEnumTypeWrapper): ...

EXTENSION_TYPE_UNSPECIFIED: ExtensionType.ValueType  # 0
EXTENSION_TYPE_SYNONYMS: ExtensionType.ValueType  # 1
EXTENSION_TYPE_STOPWORDS: ExtensionType.ValueType  # 2
global___ExtensionType = ExtensionType



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.mdb.clickhouse.v1.cluster_extension_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetClusterExtensionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    EXTENSION_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    extension_name: builtins.str
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        extension_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "extension_name", b"extension_name"]) -> None: ...

global___GetClusterExtensionRequest = GetClusterExtensionRequest

@typing.final
class ListClusterExtensionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    page_size: builtins.int
    page_token: builtins.str
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListClusterExtensionsRequest = ListClusterExtensionsRequest

@typing.final
class ListClusterExtensionsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXTENSIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    @property
    def extensions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.mdb.clickhouse.v1.cluster_extension_pb2.ClusterExtension]: ...
    def __init__(
        self,
        *,
        extensions: collections.abc.Iterable[yandex.cloud.mdb.clickhouse.v1.cluster_extension_pb2.ClusterExtension] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["extensions", b"extensions", "next_page_token", b"next_page_token"]) -> None: ...

global___ListClusterExtensionsResponse = ListClusterExtensionsResponse

@typing.final
class CreateClusterExtensionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    EXTENSION_SPEC_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    @property
    def extension_spec(self) -> global___ExtensionSpec: ...
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        extension_spec: global___ExtensionSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["extension_spec", b"extension_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "extension_spec", b"extension_spec"]) -> None: ...

global___CreateClusterExtensionRequest = CreateClusterExtensionRequest

@typing.final
class CreateClusterExtensionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    EXTENSION_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    extension_name: builtins.str
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        extension_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "extension_name", b"extension_name"]) -> None: ...

global___CreateClusterExtensionMetadata = CreateClusterExtensionMetadata

@typing.final
class DeleteClusterExtensionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    EXTENSION_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    extension_name: builtins.str
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        extension_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "extension_name", b"extension_name"]) -> None: ...

global___DeleteClusterExtensionRequest = DeleteClusterExtensionRequest

@typing.final
class DeleteClusterExtensionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    EXTENSION_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    extension_name: builtins.str
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        extension_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "extension_name", b"extension_name"]) -> None: ...

global___DeleteClusterExtensionMetadata = DeleteClusterExtensionMetadata

@typing.final
class UpdateClusterExtensionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    EXTENSION_SPEC_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    @property
    def extension_spec(self) -> global___ExtensionSpec: ...
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        extension_spec: global___ExtensionSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["extension_spec", b"extension_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "extension_spec", b"extension_spec"]) -> None: ...

global___UpdateClusterExtensionRequest = UpdateClusterExtensionRequest

@typing.final
class UpdateClusterExtensionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    EXTENSION_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    extension_name: builtins.str
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        extension_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "extension_name", b"extension_name"]) -> None: ...

global___UpdateClusterExtensionMetadata = UpdateClusterExtensionMetadata

@typing.final
class SetClusterExtensionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    EXTENSION_SPECS_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    @property
    def extension_specs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ExtensionSpec]: ...
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        extension_specs: collections.abc.Iterable[global___ExtensionSpec] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "extension_specs", b"extension_specs"]) -> None: ...

global___SetClusterExtensionsRequest = SetClusterExtensionsRequest

@typing.final
class SetClusterExtensionsMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    ADDED_EXTENSION_NAMES_FIELD_NUMBER: builtins.int
    UPDATED_EXTENSION_NAMES_FIELD_NUMBER: builtins.int
    DELETED_EXTENSION_NAMES_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    @property
    def added_extension_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def updated_extension_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def deleted_extension_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        added_extension_names: collections.abc.Iterable[builtins.str] | None = ...,
        updated_extension_names: collections.abc.Iterable[builtins.str] | None = ...,
        deleted_extension_names: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["added_extension_names", b"added_extension_names", "cluster_id", b"cluster_id", "deleted_extension_names", b"deleted_extension_names", "updated_extension_names", b"updated_extension_names"]) -> None: ...

global___SetClusterExtensionsMetadata = SetClusterExtensionsMetadata

@typing.final
class ExtensionSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    name: builtins.str
    version: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "version", b"version"]) -> None: ...

global___ExtensionSpec = ExtensionSpec



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.dataproc.v1.job_pb2
import yandex.cloud.dataproc.v1.job_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class JobServiceStub:
    """A set of methods for managing Yandex Data Processing jobs."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.dataproc.v1.job_service_pb2.ListJobsRequest,
        yandex.cloud.dataproc.v1.job_service_pb2.ListJobsResponse,
    ]
    """Retrieves a list of jobs for a cluster."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.dataproc.v1.job_service_pb2.CreateJobRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a job for a cluster."""

    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.dataproc.v1.job_service_pb2.GetJobRequest,
        yandex.cloud.dataproc.v1.job_pb2.Job,
    ]
    """Returns the specified job."""

    ListLog: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.dataproc.v1.job_service_pb2.ListJobLogRequest,
        yandex.cloud.dataproc.v1.job_service_pb2.ListJobLogResponse,
    ]
    """Returns a log for specified job."""

    Cancel: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.dataproc.v1.job_service_pb2.CancelJobRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Cancels the specified Yandex Data Processing job."""

class JobServiceAsyncStub:
    """A set of methods for managing Yandex Data Processing jobs."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.dataproc.v1.job_service_pb2.ListJobsRequest,
        yandex.cloud.dataproc.v1.job_service_pb2.ListJobsResponse,
    ]
    """Retrieves a list of jobs for a cluster."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.dataproc.v1.job_service_pb2.CreateJobRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a job for a cluster."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.dataproc.v1.job_service_pb2.GetJobRequest,
        yandex.cloud.dataproc.v1.job_pb2.Job,
    ]
    """Returns the specified job."""

    ListLog: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.dataproc.v1.job_service_pb2.ListJobLogRequest,
        yandex.cloud.dataproc.v1.job_service_pb2.ListJobLogResponse,
    ]
    """Returns a log for specified job."""

    Cancel: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.dataproc.v1.job_service_pb2.CancelJobRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Cancels the specified Yandex Data Processing job."""

class JobServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing Yandex Data Processing jobs."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.dataproc.v1.job_service_pb2.ListJobsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.dataproc.v1.job_service_pb2.ListJobsResponse, collections.abc.Awaitable[yandex.cloud.dataproc.v1.job_service_pb2.ListJobsResponse]]:
        """Retrieves a list of jobs for a cluster."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.dataproc.v1.job_service_pb2.CreateJobRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a job for a cluster."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.dataproc.v1.job_service_pb2.GetJobRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.dataproc.v1.job_pb2.Job, collections.abc.Awaitable[yandex.cloud.dataproc.v1.job_pb2.Job]]:
        """Returns the specified job."""

    @abc.abstractmethod
    def ListLog(
        self,
        request: yandex.cloud.dataproc.v1.job_service_pb2.ListJobLogRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.dataproc.v1.job_service_pb2.ListJobLogResponse, collections.abc.Awaitable[yandex.cloud.dataproc.v1.job_service_pb2.ListJobLogResponse]]:
        """Returns a log for specified job."""

    @abc.abstractmethod
    def Cancel(
        self,
        request: yandex.cloud.dataproc.v1.job_service_pb2.CancelJobRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Cancels the specified Yandex Data Processing job."""

def add_JobServiceServicer_to_server(servicer: JobServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.ai.foundation_models.v1.text_classification.text_classification_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class TextClassificationRequest(google.protobuf.message.Message):
    """Request for the service to classify text with tuned model.

    The names of the classes between which the model will be distributing requests must be specified during model tuning;
    therefore, they are not provided in the request.

    For examples of usage, see [step-by-step guides](/docs/foundation-models/operations/classifier/additionally-trained).
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_URI_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    model_uri: builtins.str
    """The [URI](/docs/foundation-models/concepts/classifier/models) of your tuned classifier model."""
    text: builtins.str
    """Text for classification."""
    def __init__(
        self,
        *,
        model_uri: builtins.str = ...,
        text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["model_uri", b"model_uri", "text", b"text"]) -> None: ...

global___TextClassificationRequest = TextClassificationRequest

@typing.final
class TextClassificationResponse(google.protobuf.message.Message):
    """Response with classifier predictions."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PREDICTIONS_FIELD_NUMBER: builtins.int
    MODEL_VERSION_FIELD_NUMBER: builtins.int
    INPUT_TOKENS_FIELD_NUMBER: builtins.int
    model_version: builtins.str
    """The model version changes with each new releases."""
    input_tokens: builtins.int
    """Number of input tokens"""
    @property
    def predictions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.ai.foundation_models.v1.text_classification.text_classification_pb2.ClassificationLabel]:
        """The classification results with the `confidence`` values
        for the probability of classifying the request text into each class.
        """

    def __init__(
        self,
        *,
        predictions: collections.abc.Iterable[yandex.cloud.ai.foundation_models.v1.text_classification.text_classification_pb2.ClassificationLabel] | None = ...,
        model_version: builtins.str = ...,
        input_tokens: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["input_tokens", b"input_tokens", "model_version", b"model_version", "predictions", b"predictions"]) -> None: ...

global___TextClassificationResponse = TextClassificationResponse

@typing.final
class FewShotTextClassificationRequest(google.protobuf.message.Message):
    """Request for the service to classify text.
    For examples of usage, see [step-by-step guides](/docs/foundation-models/operations/classifier/readymade).
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_URI_FIELD_NUMBER: builtins.int
    TASK_DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    SAMPLES_FIELD_NUMBER: builtins.int
    model_uri: builtins.str
    """The [URI](/docs/foundation-models/concepts/classifier/models) of the classifier model."""
    task_description: builtins.str
    """Text description of the classification task."""
    text: builtins.str
    """Text for classification."""
    @property
    def labels(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of available labels for the classification result.
        Give meaningful names to label classes: this is essential for correct classification results.
        For example, use ``chemistry`` and ``physics`` rather than ``chm`` and ``phs`` for class names.
        """

    @property
    def samples(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.ai.foundation_models.v1.text_classification.text_classification_pb2.ClassificationSample]:
        """Optional set of text samples with expected labels that may be used as an additional hint for the classifier."""

    def __init__(
        self,
        *,
        model_uri: builtins.str = ...,
        task_description: builtins.str = ...,
        labels: collections.abc.Iterable[builtins.str] | None = ...,
        text: builtins.str = ...,
        samples: collections.abc.Iterable[yandex.cloud.ai.foundation_models.v1.text_classification.text_classification_pb2.ClassificationSample] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["labels", b"labels", "model_uri", b"model_uri", "samples", b"samples", "task_description", b"task_description", "text", b"text"]) -> None: ...

global___FewShotTextClassificationRequest = FewShotTextClassificationRequest

@typing.final
class FewShotTextClassificationResponse(google.protobuf.message.Message):
    """Response containing classifier predictions."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PREDICTIONS_FIELD_NUMBER: builtins.int
    MODEL_VERSION_FIELD_NUMBER: builtins.int
    INPUT_TOKENS_FIELD_NUMBER: builtins.int
    model_version: builtins.str
    """The model version changes with each new releases."""
    input_tokens: builtins.int
    """Number of input tokens"""
    @property
    def predictions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.ai.foundation_models.v1.text_classification.text_classification_pb2.ClassificationLabel]:
        """The classification results with the `confidence`` values
        for the probability of classifying the request text into each class.
        """

    def __init__(
        self,
        *,
        predictions: collections.abc.Iterable[yandex.cloud.ai.foundation_models.v1.text_classification.text_classification_pb2.ClassificationLabel] | None = ...,
        model_version: builtins.str = ...,
        input_tokens: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["input_tokens", b"input_tokens", "model_version", b"model_version", "predictions", b"predictions"]) -> None: ...

global___FewShotTextClassificationResponse = FewShotTextClassificationResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/connectionmanager/v1/postgresql.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/connectionmanager/v1/postgresql.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.connectionmanager.v1 import common_pb2 as yandex_dot_cloud_dot_connectionmanager_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2yandex/cloud/connectionmanager/v1/postgresql.proto\x12!yandex.cloud.connectionmanager.v1\x1a.yandex/cloud/connectionmanager/v1/common.proto\"j\n\x0ePostgreSQLAuth\x12L\n\ruser_password\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.connectionmanager.v1.UserPasswordAuthH\x00\x42\n\n\x08security\"\xa5\x05\n\x11PostgreSQLCluster\x12H\n\x05hosts\x18\x04 \x03(\x0b\x32\x39.yandex.cloud.connectionmanager.v1.PostgreSQLCluster.Host\x12@\n\ntls_params\x18\x03 \x01(\x0b\x32,.yandex.cloud.connectionmanager.v1.TLSParams\x1a\xf7\x03\n\x04Host\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x03\x12L\n\x04role\x18\x03 \x01(\x0e\x32>.yandex.cloud.connectionmanager.v1.PostgreSQLCluster.Host.Role\x12[\n\x0creplica_type\x18\x04 \x01(\x0e\x32\x45.yandex.cloud.connectionmanager.v1.PostgreSQLCluster.Host.ReplicaType\x12P\n\x06health\x18\x05 \x01(\x0e\x32@.yandex.cloud.connectionmanager.v1.PostgreSQLCluster.Host.Health\"5\n\x04Role\x12\x14\n\x10ROLE_UNSPECIFIED\x10\x00\x12\n\n\x06MASTER\x10\x01\x12\x0b\n\x07REPLICA\x10\x02\"L\n\x0bReplicaType\x12\x1c\n\x18REPLICA_TYPE_UNSPECIFIED\x10\x00\x12\t\n\x05\x41SYNC\x10\x01\x12\x08\n\x04SYNC\x10\x02\x12\n\n\x06QUORUM\x10\x03\"Q\n\x06Health\x12\x16\n\x12HEALTH_UNSPECIFIED\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\x12\x0c\n\x08\x44\x45GRADED\x10\x03\x12\x0c\n\x08READONLY\x10\x04J\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03\"\xd3\x01\n\x14PostgreSQLConnection\x12\x45\n\x07\x63luster\x18\x01 \x01(\x0b\x32\x34.yandex.cloud.connectionmanager.v1.PostgreSQLCluster\x12\x1a\n\x12managed_cluster_id\x18\x02 \x01(\t\x12?\n\x04\x61uth\x18\x04 \x01(\x0b\x32\x31.yandex.cloud.connectionmanager.v1.PostgreSQLAuth\x12\x11\n\tdatabases\x18\x05 \x03(\tJ\x04\x08\x03\x10\x04\x42\x80\x01\n%yandex.cloud.api.connectionmanager.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/connectionmanager/v1;connectionmanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.connectionmanager.v1.postgresql_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%yandex.cloud.api.connectionmanager.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/connectionmanager/v1;connectionmanager'
  _globals['_POSTGRESQLAUTH']._serialized_start=137
  _globals['_POSTGRESQLAUTH']._serialized_end=243
  _globals['_POSTGRESQLCLUSTER']._serialized_start=246
  _globals['_POSTGRESQLCLUSTER']._serialized_end=923
  _globals['_POSTGRESQLCLUSTER_HOST']._serialized_start=408
  _globals['_POSTGRESQLCLUSTER_HOST']._serialized_end=911
  _globals['_POSTGRESQLCLUSTER_HOST_ROLE']._serialized_start=697
  _globals['_POSTGRESQLCLUSTER_HOST_ROLE']._serialized_end=750
  _globals['_POSTGRESQLCLUSTER_HOST_REPLICATYPE']._serialized_start=752
  _globals['_POSTGRESQLCLUSTER_HOST_REPLICATYPE']._serialized_end=828
  _globals['_POSTGRESQLCLUSTER_HOST_HEALTH']._serialized_start=830
  _globals['_POSTGRESQLCLUSTER_HOST_HEALTH']._serialized_end=911
  _globals['_POSTGRESQLCONNECTION']._serialized_start=926
  _globals['_POSTGRESQLCONNECTION']._serialized_end=1137
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class HostEntity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FQDN_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    STARTED_AT_FIELD_NUMBER: builtins.int
    fqdn: builtins.str
    action: builtins.str
    @property
    def started_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        fqdn: builtins.str = ...,
        action: builtins.str = ...,
        started_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["started_at", b"started_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["action", b"action", "fqdn", b"fqdn", "started_at", b"started_at"]) -> None: ...

global___HostEntity = HostEntity

@typing.final
class ClusterEntity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    STARTED_AT_FIELD_NUMBER: builtins.int
    HOSTS_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    action: builtins.str
    @property
    def started_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def hosts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HostEntity]: ...
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        action: builtins.str = ...,
        started_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        hosts: collections.abc.Iterable[global___HostEntity] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["started_at", b"started_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["action", b"action", "cluster_id", b"cluster_id", "hosts", b"hosts", "started_at", b"started_at"]) -> None: ...

global___ClusterEntity = ClusterEntity

@typing.final
class OperationLog(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTITIES_FIELD_NUMBER: builtins.int
    @property
    def entities(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ClusterEntity]: ...
    def __init__(
        self,
        *,
        entities: collections.abc.Iterable[global___ClusterEntity] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["entities", b"entities"]) -> None: ...

global___OperationLog = OperationLog



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import yandex.cloud.cloudapps.workload.v1.cloud_application_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ResolveByWorkloadRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _WorkloadType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _WorkloadTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ResolveByWorkloadRequest._WorkloadType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        WORKLOAD_TYPE_UNSPECIFIED: ResolveByWorkloadRequest._WorkloadType.ValueType  # 0
        COMPUTE_INSTANCE: ResolveByWorkloadRequest._WorkloadType.ValueType  # 1
        """Compute Instance"""

    class WorkloadType(_WorkloadType, metaclass=_WorkloadTypeEnumTypeWrapper): ...
    WORKLOAD_TYPE_UNSPECIFIED: ResolveByWorkloadRequest.WorkloadType.ValueType  # 0
    COMPUTE_INSTANCE: ResolveByWorkloadRequest.WorkloadType.ValueType  # 1
    """Compute Instance"""

    WORKLOAD_TYPE_FIELD_NUMBER: builtins.int
    WORKLOAD_ID_FIELD_NUMBER: builtins.int
    workload_type: global___ResolveByWorkloadRequest.WorkloadType.ValueType
    """Type of workload. See WorkloadType."""
    workload_id: builtins.str
    """Identifier of workload"""
    def __init__(
        self,
        *,
        workload_type: global___ResolveByWorkloadRequest.WorkloadType.ValueType = ...,
        workload_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["workload_id", b"workload_id", "workload_type", b"workload_type"]) -> None: ...

global___ResolveByWorkloadRequest = ResolveByWorkloadRequest

@typing.final
class ResolveByWorkloadResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLOUD_APPLICATION_FIELD_NUMBER: builtins.int
    @property
    def cloud_application(self) -> yandex.cloud.cloudapps.workload.v1.cloud_application_pb2.CloudApplication:
        """Details of cloud application"""

    def __init__(
        self,
        *,
        cloud_application: yandex.cloud.cloudapps.workload.v1.cloud_application_pb2.CloudApplication | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cloud_application", b"cloud_application"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cloud_application", b"cloud_application"]) -> None: ...

global___ResolveByWorkloadResponse = ResolveByWorkloadResponse
